@@ -97,12 +97,6 @@ class Project(models.Model):
         related_name='projects_with_status',
     )
     description = models.TextField()
-    billing_period = models.ForeignKey(
-        'RepeatPeriod',
-        null=True,
-        blank=True,
-        related_name='projects',
-    )
 
     class Meta:
         ordering = ('name', 'status', 'type',)
@@ -201,7 +195,7 @@ class HourGroupManager(models.Manager):
                                              'hours__sum')
         )
         #Get the list of activity names and hour sums
-        activity_entries = entries.values('activity', 'activity__name', 
+        activity_entries = entries.values('activity', 'activity__name',
                                           'activity__activity_bundle')
         activity_entries = activity_entries.annotate(Sum('hours'))
         activity_entries = activity_entries.order_by('activity')
@@ -274,9 +268,52 @@ ENTRY_STATUS = (
 )
 
 
+class EntryQuerySet(models.query.QuerySet):
+    """QuerySet extension to provide filtering by billable status"""
+
+    def date_trunc(self, key='month', all_values=False):
+        select = {"day": {"date": """DATE_TRUNC('day', end_time)"""},
+                  "week": {"date": """DATE_TRUNC('week', end_time)"""},
+                  "month": {"date": """DATE_TRUNC('month', end_time)"""},
+        }
+        basic_values = (
+            'user', 'date', 'user__first_name', 'user__last_name', 'billable',
+        )
+        extra_values = (
+            'start_time', 'end_time', 'comments', 'seconds_paused', 'id',
+            'location__name', 'project__name', 'activity__name', 'status',
+        ) if all_values else ()
+        qs = self.extra(select=select[key])
+        qs = qs.values(*basic_values + extra_values)
+        qs = qs.annotate(hours=Sum('hours')).order_by('user__last_name',
+                                                      'date')
+        return qs
+
+    def timespan(self, from_date, to_date=None, span=None):
+        """
+        Takes a beginning date a filters entries. An optional to_date can be
+        specified, or a span, which is one of ('month', 'week', 'day').
+        N.B. - If given a to_date, it does not include that date, only before.
+        """
+        if span and not to_date:
+            diff = None
+            if span == 'month':
+                diff = relativedelta(months=1)
+            if span == 'week':
+                diff = relativedelta(days=7)
+            if span == 'day':
+                diff = relativedelta(days=1)
+            if diff is not None:
+                to_date = from_date + diff
+        datesQ = Q()
+        datesQ &= Q(end_time__gte=from_date)
+        datesQ &= Q(end_time__lt=to_date) if to_date else Q()
+        return self.filter(datesQ)
+
+
 class EntryManager(models.Manager):
     def get_query_set(self):
-        qs = super(EntryManager, self).get_query_set()
+        qs = EntryQuerySet(self.model)
         qs = qs.select_related('activity', 'project__type')
         # ensure our select_related are added.  Without this line later calls
         # to select_related will void ours (not sure why - probably a bug
@@ -286,23 +323,16 @@ class EntryManager(models.Manager):
                                    'timepiece_attribute.billable'})
         return qs
 
-    def date_trunc(self, key='month'):
-        qs = self.get_query_set()
-        select = {"day": {"date": """DATE_TRUNC('day', end_time)"""},
-                  "week": {"date": """DATE_TRUNC('week', end_time)"""},
-                  "month": {"date": """DATE_TRUNC('month', end_time)"""},
-        }
-        qs = qs.extra(select=select[key]).values('user', 'user__first_name',
-                                                 'user__last_name', 'date',
-                                                 'billable',)
-        qs = qs.annotate(hours=Sum('hours')).order_by('user__last_name',
-                                                      'date')
-        return qs
+    def date_trunc(self, key='month', all_values=False):
+        return self.get_query_set().date_trunc(key, all_values)
+
+    def timespan(self, from_date, to_date=None, span='month'):
+        return self.get_query_set().timespan(from_date, to_date, span)
 
 
 class EntryWorkedManager(models.Manager):
     def get_query_set(self):
-        qs = super(EntryWorkedManager, self).get_query_set()
+        qs = EntryQuerySet(self.model)
         projects = getattr(settings, 'TIMEPIECE_PROJECTS', {})
         return qs.exclude(project__in=projects.values())
 
@@ -335,7 +365,7 @@ class Entry(models.Model):
     )
 
     start_time = models.DateTimeField()
-    end_time = models.DateTimeField(blank=True, null=True)
+    end_time = models.DateTimeField(blank=True, null=True, db_index=True)
     seconds_paused = models.PositiveIntegerField(default=0)
     pause_time = models.DateTimeField(blank=True, null=True)
     comments = models.TextField(blank=True)
@@ -345,6 +375,7 @@ class Entry(models.Model):
 
     objects = EntryManager()
     worked = EntryWorkedManager()
+    no_join = models.Manager()
 
     def check_overlap(self, entry_b, **kwargs):
         """
@@ -450,13 +481,13 @@ class Entry(models.Model):
                     'from %(start_time)s to %(end_time)s' % entry_data
                     raise ValidationError(output)
         try:
-            activity_group = self.project.activity_group
-            if activity_group:
+            act_group = self.project.activity_group
+            if act_group:
                 activity = self.activity
-                if not activity_group.activities.filter(pk=activity.pk).exists():
+                if not act_group.activities.filter(pk=activity.pk).exists():
                     name = activity.name
                     err_msg = '%s is not allowed for this project. ' % name
-                    allowed = activity_group.activities.filter()
+                    allowed = act_group.activities.filter()
                     allowed = allowed.values_list('name', flat=True)
                     allowed_names = ['among ']
                     if len(allowed) > 1:
@@ -567,13 +598,6 @@ class Entry(models.Model):
             if not self.start_time:
                 self.start_time = datetime.datetime.now()
 
-    def __billing_window(self):
-        return BillingWindow.objects.get(
-            period__users=self.user,
-            date__lte=self.end_time,
-            end_date__gt=self.end_time)
-    billing_window = property(__billing_window)
-
     def __is_editable(self):
         return self.status == 'unverified'
     is_editable = property(__is_editable)
@@ -594,6 +618,50 @@ class Entry(models.Model):
         return key
     delete_key = property(__delete_key)
 
+    @staticmethod
+    def summary(user, date, end_date):
+        """
+        Returns a summary of hours worked in the given time frame, for this
+        user.  The setting TIMEPIECE_PROJECTS can be used to separate out hours
+        for paid leave that should not be included in the total worked (e.g.,
+        sick time, vacation time, etc.).  Those hours will be added to the
+        summary separately using the dictionary key set in TIMEPIECE_PROJECTS.
+        """
+        projects = getattr(settings, 'TIMEPIECE_PROJECTS', {})
+        entries = user.timepiece_entries.filter(
+            end_time__gt=date, end_time__lt=end_date)
+        data = {
+            'billable': Decimal('0'), 'non_billable': Decimal('0'),
+            'invoiced': Decimal('0'), 'uninvoiced': Decimal('0'),
+            'total': Decimal('0')
+            }
+        invoiced = entries.filter(
+            status='invoiced').aggregate(i=Sum('hours'))['i']
+        uninvoiced = entries.exclude(
+            status='invoiced').aggregate(uninv=Sum('hours'))['uninv']
+        total = entries.aggregate(s=Sum('hours'))['s']
+        if invoiced:
+            data['invoiced'] = invoiced
+        if uninvoiced:
+            data['uninvoiced'] = uninvoiced
+        if total:
+            data['total'] = total
+        billable = entries.exclude(project__in=projects.values())
+        billable = billable.values(
+            'billable',
+        ).annotate(s=Sum('hours'))
+        for row in billable:
+            if row['billable']:
+                data['billable'] += row['s']
+            else:
+                data['non_billable'] += row['s']
+        data['total_worked'] = data['billable'] + data['non_billable']
+        data['paid_leave'] = {}
+        for name, pk in projects.iteritems():
+            qs = entries.filter(project=projects[name])
+            data['paid_leave'][name] = qs.aggregate(s=Sum('hours'))['s']
+        return data
+
     def __unicode__(self):
         """
         The string representation of an instance of this class
@@ -647,219 +715,6 @@ User.clocked_in = property(lambda user: user.timepiece_entries.filter(
     end_time__isnull=True).count() > 0)
 
 
-class RepeatPeriodManager(models.Manager):
-    def update_billing_windows(self, date_boundary=None):
-        active_billing_periods = self.filter(
-            active=True,
-        ).select_related(
-            'project'
-        )
-        windows = []
-        for period in active_billing_periods:
-            windows += ((period,
-                period.update_billing_windows(date_boundary)),)
-        return windows
-
-
-class RepeatPeriod(models.Model):
-    INTERVAL_CHOICES = (
-        ('day', 'Day(s)'),
-        ('week', 'Week(s)'),
-        ('month', 'Month(s)'),
-        ('year', 'Year(s)'),
-    )
-    count = models.PositiveSmallIntegerField(
-        choices=[(x, x) for x in range(1, 32)],
-    )
-    interval = models.CharField(
-        max_length=10,
-        choices=INTERVAL_CHOICES,
-    )
-    active = models.BooleanField(default=False)
-
-    users = models.ManyToManyField(
-        User,
-        blank=True,
-        through='PersonRepeatPeriod',
-        related_name='repeat_periods',
-    )
-
-    objects = RepeatPeriodManager()
-
-    def __unicode__(self):
-        return "%d %s" % (self.count, self.get_interval_display())
-
-    def delta(self):
-        return relativedelta(**{str(self.interval + 's'): self.count})
-
-    def update_billing_windows(self, date_boundary=None):
-        if not date_boundary:
-            date_boundary = datetime.date.today()
-        windows = []
-        try:
-            window = self.billing_windows.order_by('-date').select_related()[0]
-        except IndexError:
-            window = None
-        if window:
-            start_date = window.date
-            while window.date + self.delta() <= date_boundary:
-                window.id = None
-                if window.date + self.delta() == window.end_date:
-                    # same delta as last time
-                    window.date += self.delta()
-                else:
-                    # delta changed, make sure to include extra time
-                    window.date = window.end_date
-                window.end_date += self.delta()
-                window.save(force_insert=True)
-            return self.billing_windows.filter(
-                date__gt=start_date
-            ).order_by('date')
-        else:
-            return []
-
-
-class BillingWindow(models.Model):
-    period = models.ForeignKey(RepeatPeriod, related_name='billing_windows')
-    date = models.DateField()
-    end_date = models.DateField()
-
-    class Meta:
-        get_latest_by = 'date'
-
-    def __unicode__(self):
-        return "%s through %s" % (self.date, self.end_date)
-
-    def next(self):
-        if not hasattr(self, '_next'):
-            try:
-                window = BillingWindow.objects.filter(
-                    period=self.period,
-                    date__gt=self.date,
-                ).order_by('date')[0]
-            except IndexError:
-                window = None
-            self._next = window
-        return self._next
-
-    def previous(self):
-        if not hasattr(self, '_previous'):
-            try:
-                window = BillingWindow.objects.filter(
-                    period=self.period,
-                    date__lt=self.date,
-                ).order_by('-date')[0]
-            except IndexError:
-                window = None
-            self._previous = window
-        return self._previous
-
-    def __entries(self):
-            return Entry.objects.filter(
-                end_time__lte=self.end_date,
-                end_time__gt=self.date)
-    entries = property(__entries)
-
-
-class PersonRepeatPeriod(models.Model):
-    user = models.ForeignKey(
-        User,
-        unique=True,
-        null=True,
-    )
-    repeat_period = models.ForeignKey(
-        RepeatPeriod,
-        unique=True,
-    )
-
-    def hours_in_week(self, date):
-        left, right = utils.get_week_window(date)
-        entries = Entry.worked.filter(user=self.user)
-        entries = entries.filter(
-            (Q(status='invoiced') | Q(status='approved')),
-            end_time__gt=left, end_time__lt=right,)
-        return entries.aggregate(s=Sum('hours'))['s']
-
-    def overtime_hours_in_week(self, date):
-        hours = self.hours_in_week(date)
-        if hours > 40:
-            return hours - 40
-        return 0
-
-    def total_monthly_overtime(self, day):
-        start = day.replace(day=1)
-        weeks = utils.generate_dates(start=start,
-                                     end=utils.get_last_billable_day(start))
-        overtime = Decimal('0.0')
-        for week in weeks:
-            overtime += self.overtime_hours_in_week(week)
-        return overtime
-
-    def summary(self, date, end_date, verified=True):
-        """
-        Returns a summary of hours worked in the given time frame, for this
-        user.  The setting TIMEPIECE_PROJECTS can be used to separate out hours
-        for paid leave that should not be included in the total worked (e.g.,
-        sick time, vacation time, etc.).  Those hours will be added to the
-        summary separately using the dictionary key set in TIMEPIECE_PROJECTS.
-        """
-        projects = getattr(settings, 'TIMEPIECE_PROJECTS', {})
-        user = self.user
-        entries = user.timepiece_entries.filter(
-            end_time__gt=date, end_time__lt=end_date)
-        if verified:
-            entries = entries.filter(Q(status='invoiced') | \
-                                     Q(status='approved'))
-        data = {
-            'billable': Decimal('0'), 'non_billable': Decimal('0'),
-            'invoiced': Decimal('0'), 'uninvoiced': Decimal('0'),
-            'total': Decimal('0')
-            }
-        invoiced = entries.filter(
-            status='invoiced').aggregate(i=Sum('hours'))['i']
-        uninvoiced = entries.exclude(
-            status='invoiced').aggregate(uninv=Sum('hours'))['uninv']
-        total = entries.aggregate(s=Sum('hours'))['s']
-        if invoiced:
-            data['invoiced'] = invoiced
-        if uninvoiced:
-            data['uninvoiced'] = uninvoiced
-        if total:
-            data['total'] = total
-        billable = entries.exclude(project__in=projects.values())
-        billable = billable.values(
-            'billable',
-        ).annotate(s=Sum('hours'))
-        for row in billable:
-            if row['billable']:
-                data['billable'] += row['s']
-            else:
-                data['non_billable'] += row['s']
-        data['total_worked'] = data['billable'] + data['non_billable']
-        data['paid_leave'] = {}
-        for name, pk in projects.iteritems():
-            qs = entries.filter(project=projects[name])
-            data['paid_leave'][name] = qs.aggregate(s=Sum('hours'))['s']
-        return data
-
-    def list_total_hours(self, N=2):
-        bw = BillingWindow.objects.filter(period=self.repeat_period).order_by(
-            '-date')[:N]
-        result = []
-        for b in bw:
-            result.append(self.user.timepiece_entries.filter(
-                end_time__lte=b.end_date,
-                end_time__gt=b.date
-            ).aggregate(total=Sum('hours')))
-        return result
-
-    class Meta:
-        permissions = (
-            ('view_person_time_sheet', 'Can view person\'s timesheet.'),
-            ('edit_person_time_sheet', 'Can edit person\'s timesheet.'),
-        )
-
-
 class ProjectContract(models.Model):
     CONTRACT_STATUS = (
         ('upcoming', 'Upcoming'),
