@@ -233,10 +233,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'trunc': 'week',
         }
         data = [
-            ['12/27/2010', '01/03/2011'],
-            ['10.00', '20.00'],
-            ['5.00', '10.00'],
-            ['15.00', '30.00'],
+            ['12/27/2010', '01/03/2011', 'Total'],
+            ['10.00', '20.00', '30.00'],
+            ['5.00', '10.00', '15.00'],
+            ['15.00', '30.00', '45.00'],
         ]
         args = self.argsHelper(args)
         self.checkTotals(args, data)
@@ -248,10 +248,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'trunc': 'week',
         }
         data = [
-            ['12/27/2010', '01/03/2011'],
-            ['6.00', '12.00'],
-            ['3.00', '6.00'],
-            ['9.00', '18.00'],
+            ['12/27/2010', '01/03/2011', 'Total'],
+            ['6.00', '12.00', '18.00'],
+            ['3.00', '6.00', '9.00'],
+            ['9.00', '18.00', '27.00'],
         ]
         args = self.argsHelper(args)
         self.checkTotals(args, data)
@@ -263,10 +263,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'trunc': 'week',
         }
         data = [
-            ['12/27/2010', '01/03/2011'],
-            ['4.00', '8.00'],
-            ['2.00', '4.00'],
-            ['6.00', '12.00'],
+            ['12/27/2010', '01/03/2011', 'Total'],
+            ['4.00', '8.00', '12.00'],
+            ['2.00', '4.00', '6.00'],
+            ['6.00', '12.00', '18.00'],
         ]
         args = self.argsHelper(args)
         self.checkTotals(args, data)
@@ -279,10 +279,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'trunc': 'day',
         }
         data = [
-            ['01/02/2011', '01/03/2011', '01/04/2011'],
-            ['6.00', '6.00', '6.00'],
-            ['3.00', '3.00', '3.00'],
-            ['9.00', '9.00', '9.00'],
+            ['01/02/2011', '01/03/2011', '01/04/2011', 'Total'],
+            ['6.00', '6.00', '6.00', '18.00'],
+            ['3.00', '3.00', '3.00', '9.00'],
+            ['9.00', '9.00', '9.00', '27.00'],
         ]
         self.bulk_entries()
         args = self.argsHelper(args)
@@ -296,10 +296,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'trunc': 'week',
         }
         data = [
-            ['12/27/2010', '01/03/2011'],
-            ['12.00', '24.00'],
-            ['6.00', '12.00'],
-            ['18.00', '36.00'],
+            ['12/27/2010', '01/03/2011', 'Total'],
+            ['12.00', '24.00', '36.00'],
+            ['6.00', '12.00', '18.00'],
+            ['18.00', '36.00', '54.00'],
         ]
         self.bulk_entries()
         args = self.argsHelper(args)
@@ -315,10 +315,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'trunc': 'month',
         }
         data = [
-            ['01/01/2011', '02/01/2011', '03/01/2011'],
-            ['168.00', '168.00', '168.00'],
-            ['84.00', '84.00', '84.00'],
-            ['252.00', '252.00', '252.00'],
+            ['01/01/2011', '02/01/2011', '03/01/2011', 'Total'],
+            ['168.00', '168.00', '168.00', '504.00'],
+            ['84.00', '84.00', '84.00', '252.00'],
+            ['252.00', '252.00', '252.00', '756.00'],
         ]
         self.bulk_entries(start, end)
         args = self.argsHelper(args, start, end)
@@ -336,10 +336,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'pj_select_1': self.p1.id,
         }
         data = [
-            ['01/02/2011', '01/03/2011', '01/04/2011'],
-            ['2.00', '2.00', '2.00'],
-            ['1.00', '1.00', '1.00'],
-            ['3.00', '3.00', '3.00'],
+            ['01/02/2011', '01/03/2011', '01/04/2011', 'Total'],
+            ['2.00', '2.00', '2.00', '6.00'],
+            ['1.00', '1.00', '1.00', '3.00'],
+            ['3.00', '3.00', '3.00', '9.00'],
         ]
         args = self.argsHelper(args)
         self.checkTotals(args, data)
@@ -352,10 +352,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'pj_select_1': self.p2.id
         }
         data = [
-            ['01/02/2011', '01/03/2011', '01/04/2011'],
-            ['4.00', '4.00', '4.00'],
-            ['2.00', '2.00', '2.00'],
-            ['6.00', '6.00', '6.00'],
+            ['01/02/2011', '01/03/2011', '01/04/2011', 'Total'],
+            ['4.00', '4.00', '4.00', '12.00'],
+            ['2.00', '2.00', '2.00', '6.00'],
+            ['6.00', '6.00', '6.00', '18.00'],
         ]
         args = self.argsHelper(args)
         self.checkTotals(args, data)
@@ -368,10 +368,10 @@ class TestHourlyReport(TimepieceDataTestCase):
             'pj_select_1': [self.p2.id, self.p4.id]
         }
         data = [
-            ['01/02/2011', '01/03/2011', '01/04/2011'],
-            ['6.00', '6.00', '6.00'],
-            ['3.00', '3.00', '3.00'],
-            ['9.00', '9.00', '9.00'],
+            ['01/02/2011', '01/03/2011', '01/04/2011', 'Total'],
+            ['6.00', '6.00', '6.00', '18.00'],
+            ['3.00', '3.00', '3.00', '9.00'],
+            ['9.00', '9.00', '9.00', '27.00'],
         ]
         args = self.argsHelper(args)
         self.checkTotals(args, data)
