@@ -83,52 +83,32 @@ urlpatterns = patterns('',
     ),
 
     ### time sheets ###
-    url(
-        r'^time-sheet/projects/$',
-        views.tracked_projects,
-        name='tracked_projects',
-    ),
-    url(
-        r'^time-sheet/people/$',
-        views.tracked_people,
-        name='tracked_people',
-    ),
+
+    # Reports
     url(r'^reports/$', views.hourly_report, name='hourly_report'),
     url(r'^reports/summary/$', views.summary, name='timepiece-summary'),
     url(r'^reports/payroll/$', views.payroll_summary, name='payroll_summary',),
+    # People
     url(
-        r'^time-sheet/people/create/$',
-        views.create_edit_person_time_sheet,
-        name='create_person_time_sheet',
-    ),
-    url(
-        r'^time-sheet/people/(?P<person_id>\d+)/edit/$',
-        views.create_edit_person_time_sheet,
-        name='edit_person_time_sheet',
-    ),
-    url(
-        r'^time-sheet/people/(?P<person_id>\d+)/(period/)?' +
-        r'(?:(?P<period_id>\d+)/)?(?:(?P<window_id>\d+)/)?' +
-        r'(?:(?P<hourly>hourly)/)?$',
+        r'time-sheet/people/(?P<user_id>\d+)/$',
         views.view_person_time_sheet,
         name='view_person_time_sheet',
     ),
     url(
-        r'^time-sheet/(?P<action>verify|approve)/' +
-        r'(?:(?P<person_id>\d+)/)?(?:(?P<period_id>\d+)/)?' +
-        r'(?:(?P<window_id>\d+)/)?$',
-        views.time_sheet_change_status,
-        name='time_sheet_change_status',
+        r'^time-sheet/(?P<action>verify|approve)/(?P<user_id>\d+)/' +
+        r'(?P<from_date>\d\d\d\d-\d\d-\d\d)/$',
+        views.change_person_time_sheet,
+        name='change_person_time_sheet',
     ),
+    # Projects
     url(
-        r'^time-sheet/project/(?P<project_id>\d+)/(?:(?P<window_id>\d+)/)?$',
-        views.project_time_sheet,
+        r'^time-sheet/project/(?P<pk>\d+)/$',
+        views.ProjectTimesheet.as_view(),
         name='project_time_sheet',
     ),
     url(
-        r'^time-sheet/project/(?P<project_id>\d+)/(?:(?P<window_id>\d+)/)' +
-        r'?export/$',
-        views.export_project_time_sheet,
+        r'^time-sheet/project/(?P<pk>\d+)/csv/$',
+        views.ProjectTimesheetCSV.as_view(),
         name='export_project_time_sheet',
     ),
     url(
